AllScoreConsumer
================

.. currentmodule:: pykeen.predict

.. autoclass:: AllScoreConsumer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AllScoreConsumer.flatten

   .. rubric:: Methods Summary

   .. autosummary::

      ~AllScoreConsumer.__call__

   .. rubric:: Attributes Documentation

   .. autoattribute:: flatten

   .. rubric:: Methods Documentation

   .. automethod:: __call__
